# New in 0.16.0 (2022-04-12)

This release features a refactor of {class}`~scvi.model.DestVI` ([#1457]):

1. Bug fix in cell type amortization, which leads to on par performance of cell type amortization `V_encoder` with free parameter for cell type proportions `V`.
2. Bug fix in library size in {class}`~scvi.model.CondSCVI`, that lead to downstream dependency between sum over cell type proportions `v_ind` and library size
   `library` in {class}`~scvi.model.DestVI`.
3. `neg_log_likelihood_prior` is not computed anymore on random subset of single cells but cell type specific subclustering using cluster variance `var_vprior`,
   cluster mean `mean_vprior` and cluster mixture proportion `mp_vprior` for computation. This leads to more stable results and faster computation time.
   Setting `vamp_prior_p` in {func}`~scvi.model.DestVI.from_rna_model` to the expected resolution is critical in this algorithm.
4. The new default is to also use dropout `dropout` during the decoder of {class}`~scvi.model.CondSCVI` and subsequently `dropout_decoder` in {class}`~scvi.model.DestVI`,
   we found this to be beneficial after bug fixes listed above.
5. We changed the weighting of the loss on the variances of beta and the prior of eta.

:::{note}
Due to bug fixes listed above this version of {class}`~scvi.model.DestVI` is not backwards compatible. Despite instability in training in the
outdated version, we were able to reproduce results generated with this code. We therefore do not strictly encourage to rerun old experiments.
:::

We published a new tutorial. This new tutorial incorporates a new utility package [destvi_utils](https://github.com/YosefLab/destvi_utils) that generates exploratory plots of the results of {class}`~scvi.model.DestVI`. We refer to the manual of this package for further documentation.

## Changes

-   Docs changes (installation [#1498], {class}`~scvi.model.DestVI` user guide [#1501] and [#1508], dark mode code cells [#1499]).
-   Add `backup_url` to the {meth}`~scvi.model.base.BaseModelClass.load` method of each model class, enabling automatic downloading of model save file ([#1505]).

## Breaking changes

-   Support for loading legacy loading is removed from {meth}`~scvi.model.base.BaseModelClass.load`. Utility to convert old files to the new file as been added {meth}`~scvi.model.base.BaseModelClass.convert_legacy_save` ([#1505]).
-   Breaking changes to {class}`~scvi.model.DestVI` as specified above ([#1457]).

## Bug Fixes

-   {meth}`~scvi.model.base.RNASeqMixin.get_likelihood_parameters` fix for `n_samples > 1` and `dispersion="gene_cell"` [#1504].
-   Fix backwards compatibility for legacy TOTALVI models [#1502].

## Contributors

-   [@cane11]
-   [@jjhong922]
-   [@adamgayoso]
-   [@romain-lopez]

[#1498]: https://github.com/YosefLab/scvi-tools/pull/1498
[#1499]: https://github.com/YosefLab/scvi-tools/pull/1499
[#1501]: https://github.com/YosefLab/scvi-tools/pull/1501
[#1508]: https://github.com/YosefLab/scvi-tools/pull/1508
[#1457]: https://github.com/YosefLab/scvi-tools/pull/1457
[#1502]: https://github.com/YosefLab/scvi-tools/pull/1502
[#1504]: https://github.com/YosefLab/scvi-tools/pull/1504
[#1505]: https://github.com/YosefLab/scvi-tools/pull/1505
[@cane11]: https://github.com/cane11
[@adamgayoso]: https://github.com/adamgayoso
[@romain-lopez]: https://github.com/romain-lopez
[@jjhong922]: https://github.com/jjhong922
